| Title: | Translates JSON into a simmer environment |
|---|---|
| Description: | Define a simmer simulation problem using JSON syntax. This makes for easy sharing of simulation definitions and for easily digesting a simulation definition through an API. |
| Authors: | Bart Smeets [aut, cre] |
| Maintainer: | Bart Smeets <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-09 08:33:48 UTC |
| Source: | https://github.com/r-simmer/simmer.json |
Translate JSON-based simmer problem definition into a simmer environment
deserialise(json_obj)deserialise(json_obj)
json_obj |
a string, URL or files |
For internal usage.
process_value(value)process_value(value)
value |
value to process |